@@ -2,13 +2,12 @@ static char *TEAM_LIST[] = {
 "Holger Berndt <berndth@users.sf.net>",
 "Tristan Chabredier <wwp@claws-mail.org>",
 "Ho Vit Dinh <hoa@users.sf.net>",
-"Werner Koch <wk@gnupg.org>",
+"Andrej Kacian <andrej@kacian.sk>",
 "Darko Koruga <darko@users.sf.net>",
 "Ricardo Mones Lastra <ricardo@mones.org>",
 "Colin Leroy <colin@colino.net>",
 "Paul Mangan <paul@claws-mail.org>",
 "Salvatore De Paolis <iwkse@claws-mail.org>", 
-"Fabien Vantard <fzzzzz@gmail.com>",
 NULL
 };
 
@@ -19,11 +18,13 @@ static char *EX_TEAM_LIST[] = {
 "Oliver Haertel",
 "Christoph Hohmann",
 "Alfons Hoogervorst",
+"Werner Koch",
 "Thorsten Maerz",
 "Leandro A. F. Pereira",
 "Luke Plant",
 "Martin Schaaf",
 "Carsten Schurig",
+"Fabien Vantard",
 "Sergey Vlasov",
 "Hiroyuki Yamamoto",
 NULL
@@ -32,6 +33,7 @@ NULL
 static char *TRANS_TEAM_LIST[] = {
 "[bg] Yasen Pramatarov <yasen@lindeas.com>",
 "[ca] Miquel Oliete <ktalanet@yahoo.es>",
+"[cs] David Vachulka <david@konstrukce-cad.com>",
 "[de] Stephan Sachse <white@dev-zero.com>",
 "[en_GB] Paul Mangan <paul@claws-mail.org>",
 "[es] Ricardo Mones Lastra <ricardo@mones.org>",
@@ -43,8 +45,6 @@ static char *TRANS_TEAM_LIST[] = {
 "[pl] Emilian Nowak <emil5@go2.pl>",
 "[pt_BR] Frederico Goncalves Guimaraes <fggdebian@yahoo.com.br>",
 "[ru] Aleksei Miheev <aleksei@miheev.info>",
-"[sk] Andrej Kacian <andrej@kacian.sk>",
-"[sr] Aleksandar Urosevic <urke@users.sf.net>",
 "[sv] Lars Persson Fink <lars.p.fink@gmail.com>",
 "[zh_CN] Ralgh Young <bamanzi@gmail.com>",
 NULL
@@ -83,11 +83,13 @@ static char *CONTRIBS_LIST[] = {
 "M. Benkmann",
 "Wilbert Berendsen",
 "Jean-Luc Biord",
+"Pavlo Bohmat",
 "Eugene Brevdo",
 "Andr Filipe de Assuno e Brito",
 "Henrik Carlqvist",
 "Luca Cavalli",
 "David Chalmers",
+"Wei-Lun Chao",
 "Guillaume Chazarain",
 "Tsu-Fan Cheng",
 "Manrat Chobchuen",
@@ -98,6 +100,7 @@ static char *CONTRIBS_LIST[] = {
 "Matthieu Dazy",
 "Pierric Descamps",
 "Frank Dietrich",
+"Tim Dijkstra",
 "Nicolas Doualot",
 "Felix Eckhofer",
 "Charles A. Edwards",
@@ -109,6 +112,7 @@ static char *CONTRIBS_LIST[] = {
 "Bob Forsman",
 "Matthias Frste",
 "Stoyan Genov",
+"Stavros Giannouris",
 "Thomas Gilgin",
 "Marius Glauser",
 "Thierry Godefroy",
@@ -121,6 +125,7 @@ static char *CONTRIBS_LIST[] = {
 "Mitko Haralanov",
 "Hashimoto",
 "Federico Heinz",
+"Geir Helland",
 "Jorge Van Hemelryck",
 "Higuchi",
 "Hiramatu",
@@ -171,6 +176,7 @@ static char *CONTRIBS_LIST[] = {
 "Yuuki NINOMIYA",
 "Satoshi Nagayasu",
 "Yukihiro Nakai",
+"SungHyun Nam",
 "OSHIRO Naoki",
 "Andrew Nelson",
 "Nishika",
@@ -180,11 +186,13 @@ static char *CONTRIBS_LIST[] = {
 "Ales Nosek",
 "James Noyes",
 "Jens Oberender",
+"Ofer",
 "Ohmasa",
 "Fredrik Olofssen",
 "Reza Pakdel",
 "Martin Pool",
 "Pawel Pkala",
+"Quar",
 "Don Quijote",
 "Jens Rantil",
 "Michael Rasmussen",
@@ -223,8 +231,10 @@ static char *CONTRIBS_LIST[] = {
 "Masahiro Tomita",
 "Tomita",
 "Topia",
+"Anders Troback",
 "Tsutsui",
 "Aleksandar Urosevic",
+"Petr Vanek",
 "Jeroen Versteeg",
 "Kevin Vigor",
 "Botalov Vyacheslav",
